@@ -16,28 +16,19 @@ config = {
         "API_KEY": "{{ 20|random_string }}",
         "PAYMENT_PROCESSORS": {
             "cybersource": {
+                "flex_shared_secret_key_id": "SET-ME-PLEASE",
+                "flex_shared_secret_key": "SET-ME-PLEASE",
                 "merchant_id": "SET-ME-PLEASE",
-                "profile_id": "SET-ME-PLEASE",
-                "access_key": "SET-ME-PLEASE",
-                "secret_key": "SET-ME-PLEASE",
-                "transaction_key": "SET-ME-PLEASE",
-                "payment_page_url": "https://testsecureacceptance.cybersource.com/pay",
-                "receipt_page_url": "/checkout/receipt/",
-                "cancel_checkout_path": "/checkout/cancel-checkout/",
                 "soap_api_url": "https://ics2wstest.ic3.com/commerce/1.x/transactionProcessor/CyberSourceTransaction_1.140.wsdl",
-                "send_level_2_3_details": True,
-                "sop_profile_id": "SET-ME-PLEASE",
-                "sop_access_key": "SET-ME-PLEASE",
-                "sop_secret_key": "SET-ME-PLEASE",
-                "sop_payment_page_url": "https://testsecureacceptance.cybersource.com/silent/pay",
+                "transaction_key": "SET-ME-PLEASE",
             },
             "paypal": {
                 "mode": "sandbox",
                 "client_id": "SET-ME-PLEASE",
                 "client_secret": "SET-ME-PLEASE",
-                "receipt_url": "/checkout/receipt/",
                 "cancel_checkout_path": "/checkout/cancel-checkout/",
                 "error_url": "/checkout/error/",
+                "receipt_url": "/checkout/receipt/",
             },
         },
         "ENABLE_IDENTITY_VERIFICATION": True,
@@ -73,11 +64,14 @@ config = {
             "port": 1998,
             "env": {
                 "production": {
-                    "SUPPORT_URL": "{% if ENABLE_HTTPS %}https{% else %}http{% endif %}://{{ LMS_HOST }}/contact",
-                    "CYBERSOURCE_URL": '{{ ECOMMERCE_PAYMENT_PROCESSORS.get("cybersource", {}).get("payment_page_url", "") }}',
+                    # Hardcoded in edx-platform
+                    "CURRENCY_COOKIE_NAME": "edx-price-l10n",
+                    # TODO set customizable value
+                    "CYBERSOURCE_URL": "https://testsecureacceptance.cybersource.com/silent/pay",
+                    "SUPPORT_URL": "{% if ENABLE_HTTPS %}https{% else %}http{% endif %}://{{ LMS_HOST }}/support",
                 },
                 "development": {
-                    "SUPPORT_URL": "http://{{ LMS_HOST }}:8000/contact",
+                    "SUPPORT_URL": "http://{{ LMS_HOST }}:8000/support",
                 },
             },
         },
